# 変更履歴

全てのバージョンの重要な変更はこのファイルに記録されます。

フォーマットは[Keep a Changelog](https://keepachangelog.com/ja/)に基づいています。

## [v0.3.1] - 2026-01-15

- 「マークダウンから PDF 変換」ツールでローカル画像ファイルを使って PDF を生成できる機能を追加

### 追加

- 「XLSX → PDF 変換」ツールとの連携を追加（テンプレート解析・変換実行）

## [v0.3.0] - 2025-12-22

### 追加

- 「XLSX → PDF 変換」ツールとの連携を追加（テンプレート解析・変換実行）

## [v0.2.0] - 2025-07-05

### 追加

- 「Mermaid ダイアグラムを画像変換」ツールとの連携を追加
- 「マークダウン → DOCX 変換」にテンプレート ID 指定機能を追加

### 削除

- LangChain ツール実装はサポート対象外とし削除

## [v0.1.1] - 2025-05-09

### 追加

- ローカルの Markdown ファイルパスを指定して PDF に変換する MCP ツール (`md_file_to_pdf`) を追加
- ローカルの Markdown ファイルパスを指定して DOCX に変換する MCP ツール (`md_file_to_docx`) を追加

## [v0.1.0] - 2025-04-28

### 追加

- MCP での呼び出しに対応
- 「マークダウンから PDF 変換」で PDF テンプレート ID を指定する機能を追加
- 「DOCX → ページ画像変換」ツールとの連携を追加
- 「PPTX → ページ画像変換」ツールとの連携を追加
- 「XLSX → ページ画像変換」ツールとの連携を追加

## [v0.0.4] - 2025-03-09

### 修正

- テストコードの修正：モックオブジェクトに必要な属性（url, headers, text）を追加
- VCR テストの安定性向上

## [v0.0.3] - 2025-02-21

### 追加

- CLI サポートの追加（uvx コマンドを使用）
- CLI コマンドへの進捗表示機能の追加

### 変更

- README-ja.md の削除（メインの README が日本語のため）
- CLI ドキュメントの改善（テンプレート ID のパラメータ説明を明確化）

## [v0.0.2] - 2025-02-17

### 追加

- PyPI パッケージ配布対応
- VCR テストの追加
- 最小限の利用例の追加（クライアントと LangChain ツール）
- .vscode 設定の追加（開発環境の統一化）

### 変更

- ライブラリのフォルダ構造の整理
- ドキュメントの整備と改善

### 修正

- デプロイフローの修正
- テストの修正と VCR カセットの更新
